==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/GetVirtualNodeSpecListenerOutlierDetection.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Int
import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property baseEjectionDurations
 * @property intervals
 * @property maxEjectionPercent
 * @property maxServerErrors
 */
public data class GetVirtualNodeSpecListenerOutlierDetection(
    public val baseEjectionDurations:
    List<GetVirtualNodeSpecListenerOutlierDetectionBaseEjectionDuration>,
    public val intervals: List<GetVirtualNodeSpecListenerOutlierDetectionInterval>,
    public val maxEjectionPercent: Int,
    public val maxServerErrors: Int,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.GetVirtualNodeSpecListenerOutlierDetection):
            GetVirtualNodeSpecListenerOutlierDetection = GetVirtualNodeSpecListenerOutlierDetection(
            baseEjectionDurations = javaType.baseEjectionDurations().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualNodeSpecListenerOutlierDetectionBaseEjectionDuration.Companion.toKotlin(args0)
                })
            }),
            intervals = javaType.intervals().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualNodeSpecListenerOutlierDetectionInterval.Companion.toKotlin(args0)
                })
            }),
            maxEjectionPercent = javaType.maxEjectionPercent(),
            maxServerErrors = javaType.maxServerErrors(),
        )
    }
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/outputs/GetVirtualNodeSpecListenerOutlierDetection.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.outputs

import kotlin.Int
import kotlin.Suppress
import kotlin.collections.List

/**
 *
 * @property baseEjectionDurations
 * @property intervals
 * @property maxEjectionPercent
 * @property maxServerErrors
 */
public data class GetVirtualNodeSpecListenerOutlierDetection(
    public val baseEjectionDurations: List<GetVirtualNodeSpecListenerOutlierDetectionBaseEjectionDuration>,
    public val intervals: List<GetVirtualNodeSpecListenerOutlierDetectionInterval>,
    public val maxEjectionPercent: Int,
    public val maxServerErrors: Int,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.aws.appmesh.outputs.GetVirtualNodeSpecListenerOutlierDetection): GetVirtualNodeSpecListenerOutlierDetection = GetVirtualNodeSpecListenerOutlierDetection(
            baseEjectionDurations = javaType.baseEjectionDurations().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualNodeSpecListenerOutlierDetectionBaseEjectionDuration.Companion.toKotlin(args0)
                })
            }),
            intervals = javaType.intervals().map({ args0 ->
                args0.let({ args0 ->
                    com.pulumi.aws.appmesh.kotlin.outputs.GetVirtualNodeSpecListenerOutlierDetectionInterval.Companion.toKotlin(args0)
                })
            }),
            maxEjectionPercent = javaType.maxEjectionPercent(),
            maxServerErrors = javaType.maxServerErrors(),
        )
    }
}
